Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(757)

Unified Diff: content/browser/appcache/appcache_request_handler.h

Issue 2865613002: Add an abstraction for a job in the AppCacheRequestHandler class. (Closed)
Patch Set: Fix compile failures Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/appcache/appcache_request.h ('k') | content/browser/appcache/appcache_request_handler.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/appcache/appcache_request_handler.h
diff --git a/content/browser/appcache/appcache_request_handler.h b/content/browser/appcache/appcache_request_handler.h
index 077e22b01a4bb86c4a1a8d2301ba183e9f768ce0..3b7e16736d50b3198620f2e4367daa3bce0686e3 100644
--- a/content/browser/appcache/appcache_request_handler.h
+++ b/content/browser/appcache/appcache_request_handler.h
@@ -25,6 +25,7 @@ class URLRequest;
} // namespace net
namespace content {
+class AppCacheJob;
class AppCacheRequest;
class AppCacheRequestHandlerTest;
class AppCacheURLRequestJob;
@@ -43,12 +44,11 @@ class CONTENT_EXPORT AppCacheRequestHandler
~AppCacheRequestHandler() override;
// These are called on each request intercept opportunity.
- AppCacheURLRequestJob* MaybeLoadResource(
- net::NetworkDelegate* network_delegate);
- AppCacheURLRequestJob* MaybeLoadFallbackForRedirect(
+ AppCacheJob* MaybeLoadResource(net::NetworkDelegate* network_delegate);
+ AppCacheJob* MaybeLoadFallbackForRedirect(
net::NetworkDelegate* network_delegate,
const GURL& location);
- AppCacheURLRequestJob* MaybeLoadFallbackForResponse(
+ AppCacheJob* MaybeLoadFallbackForResponse(
net::NetworkDelegate* network_delegate);
void GetExtraResponseInfo(int64_t* cache_id, GURL* manifest_url);
@@ -98,9 +98,9 @@ class CONTENT_EXPORT AppCacheRequestHandler
// restarting, so can correctly continue to handle the request.
void OnPrepareToRestart();
// Helper method to create an AppCacheURLRequestJob and populate job_.
// Caller takes ownership of returned value.
- std::unique_ptr<AppCacheURLRequestJob> CreateJob(
+ std::unique_ptr<AppCacheJob> CreateJob(
net::NetworkDelegate* network_delegate);
// Helper to retrieve a pointer to the storage object.
@@ -113,7 +113,7 @@ class CONTENT_EXPORT AppCacheRequestHandler
// Main-resource loading -------------------------------------
// Frame and SharedWorker main resources are handled here.
- std::unique_ptr<AppCacheURLRequestJob> MaybeLoadMainResource(
+ std::unique_ptr<AppCacheJob> MaybeLoadMainResource(
net::NetworkDelegate* network_delegate);
// AppCacheStorage::Delegate methods
@@ -128,7 +128,7 @@ class CONTENT_EXPORT AppCacheRequestHandler
// Sub-resource loading -------------------------------------
// Dedicated worker and all manner of sub-resources are handled here.
- std::unique_ptr<AppCacheURLRequestJob> MaybeLoadSubResource(
+ std::unique_ptr<AppCacheJob> MaybeLoadSubResource(
net::NetworkDelegate* network_delegate);
void ContinueMaybeLoadSubResource();
@@ -177,7 +177,7 @@ class CONTENT_EXPORT AppCacheRequestHandler
// 1) Before request has started a job.
// 2) Request is not being handled by appcache.
// 3) Request has been cancelled, and the job killed.
- base::WeakPtr<AppCacheURLRequestJob> job_;
+ base::WeakPtr<AppCacheJob> job_;
// During a cross site navigation, we transfer ownership the AppcacheHost
// from the old processes structures over to the new structures.
« no previous file with comments | « content/browser/appcache/appcache_request.h ('k') | content/browser/appcache/appcache_request_handler.cc » ('j') | no next file with comments »
@@ -98,9 +98,9 @@ class CONTENT_EXPORT AppCacheRequestHandler
// restarting, so can correctly continue to handle the request.
void OnPrepareToRestart();
- // Helper method to create an AppCacheURLRequestJob and populate job_.
+ // Helper method to create an AppCacheJob and populate job_.
// Caller takes ownership of returned value.

Powered by Google App Engine
This is Rietveld 408576698